/*
 * LaTeXRESTClient.java  - LaTeX REST access example
 * Author: Peter Sauer (peter.sauer@sciencesoft.at)
 * Date of last modification: 2008-09-25
 * HTTPClient: http://hc.apache.org/httpclient-3.x/userguide.html
 */

package at.sciencesoft.test;
import org.apache.commons.httpclient.*;
import org.apache.commons.httpclient.methods.*;
import sun.misc.BASE64Decoder;
import java.io.*;

public class LaTeXRESTClient {

    private static String url = "http://sciencesoft.at/latex";

    public static void writeByteStream(String fileName, byte[] stream) throws Exception {
        File file = new File(fileName);
        FileOutputStream writer = new FileOutputStream(file);
        writer.write(stream, 0, stream.length);
        writer.close();
    }
    
    public static char[] readCharStream(String fileName) throws Exception {
        File file = new File(fileName);
        FileReader reader = new FileReader(file);
        int fileLength = (int) file.length();
        char[] stream = new char[fileLength];
        reader.read(stream, 0, fileLength);
        reader.close();
        return stream;
    }

    public static void main(String[] args) throws Exception {
        String xml = new String(readCharStream(args[0]));
        // Prepare HTTP put
        PutMethod put = new PutMethod(url);
        // Request content will be retrieved directly
        // from the input stream
        put.setRequestHeader("Content-Type", "text/xml;charset=utf-8");
        put.setRequestEntity(new StringRequestEntity(xml, null, "utf-8"));
        // Get HTTP client
        HttpClient httpclient = new HttpClient();
        // Execute request
        try {
            int result = httpclient.executeMethod(put);
            // Display status code
            System.out.println("Response status code: " + result);
            if (result == 200) {
                // fetching quick & dirty the binary data
                xml = put.getResponseBodyAsString();
                if (xml.indexOf("<success>true</success>") >= 0) {
                    int start = xml.indexOf("<data>");
                    int end = xml.indexOf("</data>");
                    if (start >= 0 && end >= 0) {
                        start += "<data>".length();
                        writeByteStream(args[1], new BASE64Decoder().decodeBuffer(xml.substring(start, end)));
                    } else {
                        System.out.println(xml);
                    }
                } else {
                    System.out.println(xml);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            // Release current connection to the connection pool once you are done
            put.releaseConnection();
        }
    }
}

