/*
 * LaTeXRESTwidthXStream.java  - LaTeX REST access example
 * Author: Peter Sauer (peter.sauer@sciencesoft.at)
 * Date of last modification: 2008-10-02
 * HTTPClient: http://hc.apache.org/httpclient-3.x/userguide.html
 */

package at.sciencesoft.test;
import org.apache.commons.httpclient.*;
import org.apache.commons.httpclient.methods.*;
import sun.misc.BASE64Decoder;
import java.io.*;
import com.thoughtworks.xstream.XStream;


public class LaTeXRESTwithXStream {

    private static String url = "http://sciencesoft.at/latex";

    public static void writeByteStream(String fileName, byte[] stream) throws Exception {
        File file = new File(fileName);
        FileOutputStream writer = new FileOutputStream(file);
        writer.write(stream, 0, stream.length);
        writer.close();
    }
    
    public static char[] readCharStream(String fileName) throws Exception {
        File file = new File(fileName);
        FileReader reader = new FileReader(file);
        int fileLength = (int) file.length();
        char[] stream = new char[fileLength];
        reader.read(stream, 0, fileLength);
        reader.close();
        return stream;
    }

    public static void main(String[] args) throws Exception {
        String xml = new String(readCharStream(args[0]));
        // Prepare HTTP put
        PutMethod put = new PutMethod(url);
        // Request content will be retrieved directly
        // from the input stream
        put.setRequestHeader("Content-Type", "text/xml;charset=utf-8");
        put.setRequestEntity(new StringRequestEntity(xml, null, "utf-8"));
        // Get HTTP client
        HttpClient httpclient = new HttpClient();
        // Execute request
        try {
            int result = httpclient.executeMethod(put);
            // Display status code
            System.out.println("Response status code: " + result);
            if (result == 200) {
                xml = put.getResponseBodyAsString();
                // change the package dependency
                xml = xml.replaceAll("RESTlatexResult>", "at.sciencesoft.test.RESTlatexResult>");

                XStream xstream = new XStream();          
                RESTlatexResult rlr = (RESTlatexResult)xstream.fromXML(xml);

                if (rlr.success) {
                   writeByteStream(args[1], rlr.data);
                } else {
                    System.out.println(rlr.error);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            // Release current connection to the connection pool once you are done
            put.releaseConnection();
        }
    }
}

